<?php
/**
 * ownCloud Admin_Audit
 *
 * @author Joas Schilling <nickvergessen@owncloud.com>
 * @copyright (C) 2016 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Admin_Audit\Handlers;

use OCP\IUser;
use OCP\Defaults;

class Session extends Base {
	/** @var Defaults  */
	private static $defaults;

	/**
	 * Session constructor.
	 *
	 * @param Defaults $defaults
	 */
	public function __construct(Defaults $defaults) {
		self::$defaults = $defaults;
	}

	/**
	 * Log login attempt
	 * @param string[] $params
	 */
	public static function pre_login($params) {
		if (isset($params['login'])) {
			$login = $params['login'];
		} elseif (isset($params['uid'])) {
			$login = $params['uid'];
		} else {
			return;
		}
		self::getLogger()->log('User {user} attempted to log into {productName} from IP address: {ip}', [
			'user' => $login,
			'productName' => self::$defaults->getName()
		]);
	}

	/**
	 * Log successful login
	 * @param string[] $params
	 */
	public static function post_login($params) {
		if (isset($params['login'])) {
			$login = $params['login'];
		} elseif (isset($params['uid'])) {
			$login = $params['uid'];
		} else {
			return;
		}
		self::getLogger()->log('User {user} logged into {productName} from IP address: {ip}', [
			'user' => $login,
			'productName' => self::$defaults->getName()
		]);
	}

	/**
	 * Log logout
	 */
	public static function logout() {
		$logger = self::getLogger();
		$user = $logger->getSessionUser();

		if ($user instanceof IUser) {
			$logger->log('User {user} logged out of {productName}', [
				'user' => $user->getUID(),
				'productName' => self::$defaults->getName()
			]);
		}
	}
}
